bq\_properties\_creator package
===============================

Submodules
----------

bq\_properties\_creator.bq\_properties\_creator module
------------------------------------------------------

.. automodule:: bq_properties_creator.bq_properties_creator
    :members:
    :undoc-members:
    :show-inheritance:

bq\_properties\_creator.cli module
----------------------------------

.. automodule:: bq_properties_creator.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: bq_properties_creator
    :members:
    :undoc-members:
    :show-inheritance:
